==> jc-1.4.0.tar.gz: scm/Cell.h <==
// class scm.Cell

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e5a5e9dc399bf1a5 scm_Cell

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_scm_Cell_H_
#define _JC_scm_Cell_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_scm_Cell$object;
struct _jc_scm_Env$object;
struct _jc_scm_Obj$object;

// Typedefs
typedef struct _jc_scm_Cell$sub_refs	_jc_scm_Cell$sub_refs;
typedef struct _jc_scm_Cell$sub_nonrefs	_jc_scm_Cell$sub_nonrefs;
typedef struct _jc_scm_Cell$refs	_jc_scm_Cell$refs;
typedef struct _jc_scm_Cell$nonrefs	_jc_scm_Cell$nonrefs;
typedef struct _jc_scm_Cell$object	_jc_scm_Cell$object;

typedef const struct _jc_scm_Cell$vmethods	_jc_scm_Cell$vmethods;
typedef const struct _jc_scm_Cell$vtable	_jc_scm_Cell$vtable;
typedef const struct _jc_scm_Cell$vtype	_jc_scm_Cell$vtype;

// Constructors
extern void _jc_scm_Cell$method$_init$12568684e8c7390d(_jc_env *, struct _jc_scm_Cell$object *, struct _jc_object *, struct _jc_scm_Cell$object *);

// Virtual methods
extern struct _jc_object *_jc_scm_Cell$method$eval$45e01bedb73fc9c4(_jc_env *, struct _jc_scm_Cell$object *, struct _jc_scm_Env$object *);
extern struct _jc_java_lang_String$object *_jc_scm_Cell$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_scm_Cell$object *);
extern struct _jc_java_lang_String$object *_jc_scm_Cell$method$toString$6c66978ce928e6cb(_jc_env *, struct _jc_scm_Cell$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_scm_Cell$method_info$eval$45e01bedb73fc9c4;
extern _jc_method _jc_scm_Cell$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_scm_Cell$method_info$toString$6c66978ce928e6cb;

// Virtual methods structure
struct _jc_scm_Cell$vmethods {
	struct _jc_object	*(*eval$45e01bedb73fc9c4)(_jc_env *, struct _jc_scm_Cell$object *, struct _jc_scm_Env$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_scm_Cell$object *);
	struct _jc_java_lang_String$object	*(*toString$6c66978ce928e6cb)(_jc_env *, struct _jc_scm_Cell$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_scm_Cell$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_scm_Cell$vmethods	scm_Cell;
};

// Vtype
struct _jc_scm_Cell$vtype {
	_jc_type			type;
	_jc_scm_Cell$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_scm_Cell$sub_refs {
	struct _jc_object	*car;
	struct _jc_scm_Cell$object	*cdr;
};

// Reference instance fields (object)
struct _jc_scm_Cell$refs {
    _jc_scm_Cell$sub_refs	scm_Cell;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_scm_Cell$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_scm_Cell$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_scm_Cell$sub_nonrefs	scm_Cell;
};

// Object instance structure
struct _jc_scm_Cell$object {
	_jc_scm_Cell$refs	refs[0];
	_jc_word		lockword;
	_jc_scm_Cell$vtype	*vtype;
	_jc_scm_Cell$nonrefs	nonrefs;
};

// Type structure
extern _jc_scm_Cell$vtype _jc_scm_Cell$type;

// Array types class info structures
_JC_DECL_ARRAYS(scm_Cell, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_scm_Cell$class_object;

#endif	/* _JC_scm_Cell_H_ */

==> jc-1.4.6.tar.gz: scm/Cell.h <==
// class scm.Cell

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e5a5e9dc399bf1a5 scm_Cell

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_scm_Cell_H_
#define _JC_scm_Cell_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_scm_Cell$object;
struct _jc_scm_Env$object;
struct _jc_scm_Obj$object;

// Typedefs
typedef struct _jc_scm_Cell$sub_refs	_jc_scm_Cell$sub_refs;
typedef struct _jc_scm_Cell$sub_nonrefs	_jc_scm_Cell$sub_nonrefs;
typedef struct _jc_scm_Cell$refs	_jc_scm_Cell$refs;
typedef struct _jc_scm_Cell$nonrefs	_jc_scm_Cell$nonrefs;
typedef struct _jc_scm_Cell$object	_jc_scm_Cell$object;

typedef const struct _jc_scm_Cell$vmethods	_jc_scm_Cell$vmethods;
typedef const struct _jc_scm_Cell$vtable	_jc_scm_Cell$vtable;
typedef const struct _jc_scm_Cell$vtype	_jc_scm_Cell$vtype;

// Constructors
extern void _jc_scm_Cell$method$_init$12568684e8c7390d(_jc_env *, struct _jc_scm_Cell$object *, struct _jc_object *, struct _jc_scm_Cell$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_scm_Cell$method$eval$45e01bedb73fc9c4(_jc_env *, struct _jc_scm_Cell$object *, struct _jc_scm_Env$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_scm_Cell$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_scm_Cell$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_scm_Cell$method$toString$6c66978ce928e6cb(_jc_env *, struct _jc_scm_Cell$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_scm_Cell$method_info$eval$45e01bedb73fc9c4;
extern _jc_method _jc_scm_Cell$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_scm_Cell$method_info$toString$6c66978ce928e6cb;

// Virtual methods structure
struct _jc_scm_Cell$vmethods {
	struct _jc_object	*(*eval$45e01bedb73fc9c4)(_jc_env *, struct _jc_scm_Cell$object *, struct _jc_scm_Env$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_scm_Cell$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$6c66978ce928e6cb)(_jc_env *, struct _jc_scm_Cell$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_scm_Cell$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_scm_Cell$vmethods	scm_Cell;
};

// Vtype
struct _jc_scm_Cell$vtype {
	_jc_type			type;
	_jc_scm_Cell$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_scm_Cell$sub_refs {
	struct _jc_object	*car;
	struct _jc_scm_Cell$object	*cdr;
};

// Reference instance fields (object)
struct _jc_scm_Cell$refs {
    _jc_scm_Cell$sub_refs	scm_Cell;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_scm_Cell$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_scm_Cell$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_scm_Cell$sub_nonrefs	scm_Cell;
};

// Object instance structure
struct _jc_scm_Cell$object {
	_jc_scm_Cell$refs	refs[0];
	_jc_word		lockword;
	_jc_scm_Cell$vtype	*vtype;
	_jc_scm_Cell$nonrefs	nonrefs;
};

// Type structure
extern _jc_scm_Cell$vtype _jc_scm_Cell$type;

// Array types class info structures
_JC_DECL_ARRAYS(scm_Cell, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_scm_Cell$class_object;

#endif	/* _JC_scm_Cell_H_ */
